<?php
if (!function_exists('jumla_banner_slider_args')) :
    /**
     * Banner Slider Details
     *
     * @since Jumla 1.0.0
     *
     * @return array $qargs Slider details.
     */
    function jumla_banner_slider_args()
    {
        $jumla_banner_slider_number = absint(jumla_get_option('number_of_home_slider'));
        $jumla_banner_slider_category = absint(jumla_get_option('select_category_for_slider'));
        $qargs = array(
            'posts_per_page' => absint($jumla_banner_slider_number),
            'post_type' => 'post',
            'cat' => absint($jumla_banner_slider_category),
        );
        return $qargs;
    }
endif;


if (!function_exists('jumla_banner_slider')) :
    /**
     * Banner Slider
     *
     * @since Jumla 1.0.0
     *
     */
    function jumla_banner_slider()
    {
        $jumla_slider_button_text = esc_html(jumla_get_option('button_text_on_slider'));
        $jumla_slider_excerpt_number = absint(jumla_get_option('number_of_content_home_slider'));
        if (1 != jumla_get_option('show_slider_section')) {
            return null;
        }
        $jumla_banner_slider_args = jumla_banner_slider_args();
        $jumla_banner_slider_query = new WP_Query($jumla_banner_slider_args); ?>
        <section class="section-block twp-banner">
            <div class="wrapper">
                <div class="col-row col-row-sm">
                    <?php 
                    $cat_class = '';
                    if (1 == jumla_get_option('show_cat_post_list')) {
                        $cat_class= 'col-seven';
                    } else{
                        $cat_class= 'col-full';
                    } ?>
                    <div class="col col-sm <?php echo esc_attr($cat_class); ?> col-sm-full">
                        <div class="twp-slider twp-slider-1">
                            <?php
                            if ($jumla_banner_slider_query->have_posts()) :
                                while ($jumla_banner_slider_query->have_posts()) : $jumla_banner_slider_query->the_post();
                                    if (has_excerpt()) {
                                        $jumla_slider_content = get_the_excerpt();
                                    } else {
                                        $jumla_slider_content = jumla_words_count($jumla_slider_excerpt_number, get_the_content());
                                    }
                                    ?>
                                    <div class="single-slide">
                                        <div class="col-row">
                                            <div class="col col-six pull-right">
                                                <?php if (has_post_thumbnail()) {
                                                    $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'jumla-slider-img');
                                                    $url = $thumb['0']; ?>
                                                    <div class="slide-bg bg-image">
                                                        <img src="<?php echo esc_url($url); ?>">
                                                    </div>
                                                <?php } ?>
                                            </div>
                                            <div class="col col-four">
                                                <div class="slide-text">
                                                    <h2 class="slide-title"><?php the_title(); ?></h2>
                                                    <?php if ($jumla_slider_excerpt_number != 0) { ?>
                                                        <p class="hide-sm"><?php echo wp_kses_post($jumla_slider_content); ?></p>
                                                    <?php } ?>
                                                    <a href="<?php the_permalink(); ?>" class="btn btn-primary">
                                                        <?php echo esc_html($jumla_slider_button_text); ?>
                                                    </a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php
                                endwhile;
                                wp_reset_postdata();
                            endif; ?>
                        </div>
                    </div>
                    <?php 
                    $cat_class = '';
                    if (1 == jumla_get_option('show_cat_post_list')) { ?>
                      <div class="col col-sm col-three-1 col-sm-full">
                          <?php
                          $jumla_slider_side_cat_list = absint(jumla_get_option('select_category_for_list'));
                          if (!empty($jumla_slider_side_cat_list)) {
                              $jumla_side_post_page_args = array(
                                  'post_type' => 'post',
                                  'cat' => absint($jumla_slider_side_cat_list),
                                  'posts_per_page' => 4,
                              );
                          }
                          if (!empty($jumla_side_post_page_args)) {
                              $jumla_side_post_page_query = new WP_Query($jumla_side_post_page_args);
                              while ($jumla_side_post_page_query->have_posts()): $jumla_side_post_page_query->the_post(); ?>
                                  <div class="featured-block">
                                      <div class="featured-blog-list clear">
                                          <?php if (has_post_thumbnail()) { ?>
                                              <div class="featured-image">
                                                  <?php the_post_thumbnail('thumbnail'); ?>
                                              </div>
                                          <?php } ?>
                                          <div class="featured-details">
                                              <h3 class="entry-title primary-font">
                                                  <a href="<?php the_permalink() ?>">
                                                  <?php the_title(); ?>
                                                  </a>
                                              </h3>
                                              <div class="entry-meta">
                                                  <?php jumla_posted_date_only(); ?>
                                              </div>
                                          </div>
                                      </div>
                                  </div>
                          <?php endwhile;
                              wp_reset_postdata();
                          } ?>
                      </div> 
                    <?php } ?>
                </div>
            </div>
        </section>
        <?php
    }
endif;
add_action('jumla_action_slider_post', 'jumla_banner_slider', 10);